@@ -7,7 +7,7 @@ use 5.010_000;
 use File::ShareDir 'dist_dir';
 use Path::Class;
 
-our $VERSION = '2.012003_001';
+our $VERSION = '2.017001_001';
 
 BEGIN {
   if (not ($ENV{DANCER_APPDIR} || '')
@@ -82,15 +82,45 @@ App::Netdisco - An open source web-based network management tool.
 
 =head1 Introduction
 
-The content of this distribution is the next major version of the Netdisco
-network management tool. Pieces are still missing however, so if you're a new
-user please see L<http://netdisco.org/> for further information on the project
-and how to download the current official release.
+Netdisco is a web-based network management tool designed for network
+administrators. Data is collected into a PostgreSQL database using SNMP.
+
+Some of the things you can do with Netdisco:
+
+=over 4
+
+=item *
+
+B<Locate> a machine on the network by MAC or IP and show the switch port it
+lives at
+
+=item *
+
+B<Turn off> a switch port, or change the VLAN or PoE status of a port
+
+=item *
+
+B<Inventory> your network hardware by model, vendor, software and operating
+system
+
+=item *
+
+B<Pretty pictures> of your network
+
+=back
 
 L<App::Netdisco> provides a web frontend with built-in web server, and a
 backend daemon to handle interactive requests such as changing port or device
 properties.
 
+=over 4
+
+=item *
+
+See the demo at: L<http://netdisco2-demo.herokuapp.com/>
+
+=back
+
 If you have any trouble getting the frontend running, speak to someone in the
 C<#netdisco> IRC channel (on freenode). Before installing or upgrading please
 review the latest L<Release Notes|App::Netdisco::Manual::ReleaseNotes>.
@@ -190,16 +220,21 @@ Run the following command to start the web-app server as a backgrounded daemon
  ~/bin/netdisco-web start
 
 If the Inventory is empty because this is a new installation, you probably
-want to either run some polling jobs from the command-line, or give a web user
-some admin rights (TODO: user rights management).
+want to run some polling jobs. This can be done from from the web interface or
+command-line (see L<netdisco-do>).
 
 Run the following command to start the job control daemon (port control, etc):
 
  ~/bin/netdisco-daemon start
 
-You should take care not to run this Netdisco daemon and the legacy daemon at
-the same time. Similarly, if you use the device discovery with Netdisco 2,
-disable your system's cron jobs for the Netdisco 1 poller.
+You should take care not to run this Netdisco daemon and the Netdisco 1.x
+daemon at the same time. Similarly, if you use the device discovery with
+Netdisco 2, disable your system's cron jobs for the Netdisco 1.x poller.
+
+At this point you can revisit the C<~/environments/deployment.yml> file to
+uncomment more configuration. Check out the community string settings, and
+C<housekeeping> which enables the automatic periodic device discovery. See
+L<Configuration|App::Netdisco::Manual::Configuration> for further details.
 
 =head1 Upgrading
 
@@ -267,13 +302,6 @@ within the L<Developer|App::Netdisco::Manual::Developing> documentation.
 
 =head1 Caveats
 
-Some sections are not yet implemented, e.g. the I<Device Module> tab.
-
-Some menu items on the main black navigation bar go nowhere.
-
-None of the Reports yet exist (e.g. searching for wireless devices, or duplex
-mismatches). These will be implemented as a plugin bundle.
-
 The Wireless, IP Phone and NetBIOS Node properies are not yet shown.
 
 =head1 AUTHOR
