@@ -1,7 +1,7 @@
 package App::Netdisco::Util::SNMP;
 
 use Dancer qw/:syntax :script/;
-use App::Netdisco::Util::Device 'get_device';
+use App::Netdisco::Util::Device qw/get_device check_no/;
 
 use SNMP::Info;
 use Try::Tiny;
@@ -65,11 +65,28 @@ sub _snmp_connect_generic {
     DestHost => $device->ip,
     Retries => (setting('snmpretries') || 2),
     Timeout => (setting('snmptimeout') || 1000000),
+    NonIncreasing => (setting('nonincreasing') || 0),
+    BulkWalk => ((defined setting('bulkwalk_off') && setting('bulkwalk_off'))
+                 ? 0 : 1),
+    BulkRepeaters => (setting('bulkwalk_repeaters') || 20),
     MibDirs => [ _build_mibdirs() ],
     IgnoreNetSNMPConf => 1,
     Debug => ($ENV{INFO_TRACE} || 0),
   );
 
+  # an override for bulkwalk
+  $snmp_args{BulkWalk} = 0 if check_no($device, 'bulkwalk_no');
+
+  # further protect against buggy Net-SNMP, and disable bulkwalk
+  if ($snmp_args{BulkWalk}
+      and ($SNMP::VERSION eq '5.0203' || $SNMP::VERSION eq '5.0301')) {
+
+      warning sprintf
+        "[%s] turning off BulkWalk due to buggy Net-SNMP - please upgrade!",
+        $device->ip;
+      $snmp_args{BulkWalk} = 0;
+  }
+
   # TODO: add version force support
   # use existing SNMP version or try 2, 1
   my @versions = (($device->snmp_ver || setting('snmpver') || 2));
@@ -90,19 +107,27 @@ sub _snmp_connect_generic {
   unshift @communities, $device->snmp_comm
     if defined $device->snmp_comm
        and defined $comm_type and $comm_type eq 'community';
+  unshift @communities, $device->community->snmp_comm_rw
+    if eval { $device->community->snmp_comm_rw }
+       and defined $comm_type and $comm_type eq 'community_rw';
 
   my $info = undef;
   VERSION: foreach my $ver (@versions) {
-      next unless length $ver;
+      next unless $ver;
 
       CLASS: foreach my $class (@classes) {
-          next unless length $class;
+          next unless $class;
 
           COMMUNITY: foreach my $comm (@communities) {
-              next unless length $comm;
+              next unless $comm;
 
-              $info = _try_connect($ver, $class, $comm, \%snmp_args)
-                and last VERSION;
+              $info = _try_connect($ver, $class, $comm, \%snmp_args);
+
+              if ($comm_type eq 'community_rw') {
+                  _try_write($info, $comm, $device) or next COMMUNITY;
+              }
+
+              last VERSION if $info;
           }
       }
   }
@@ -110,6 +135,25 @@ sub _snmp_connect_generic {
   return $info;
 }
 
+sub _try_write {
+  my ($info, $comm, $device) = @_;
+  my $happy = 0;
+
+  try {
+      debug sprintf '[%s] try_write with comm: %s', $device->ip, $comm;
+      $info->clear_cache;
+      my $rv = $info->set_location( $info->location );
+      $device->update_or_create_related('community', {snmp_comm_rw => $comm})
+        if $device->in_storage;
+      $happy = 1 if $rv;
+  }
+  catch {
+      debug $_;
+  };
+
+  return $happy;
+}
+
 sub _try_connect {
   my ($ver, $class, $comm, $snmp_args) = @_;
   my $info = undef;
@@ -147,14 +191,14 @@ sub _try_connect {
 }
 
 sub _build_mibdirs {
-  my $home = (setting('mibhome') || $ENV{NETDISCO_HOME} || $ENV{HOME});
-  return map { dir($home, $_) }
+  my $home = (setting('mibhome') || dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'netdisco-mibs'));
+  return map { dir($home, $_)->stringify }
              @{ setting('mibdirs') || _get_mibdirs_content($home) };
 }
 
 sub _get_mibdirs_content {
   my $home = shift;
-  warning 'Netdisco SNMP work will be really slow - loading ALL MIBs. Please set mibdirs.';
+  # warning 'Netdisco SNMP work will be slow - loading ALL MIBs. Consider setting mibdirs.';
   my @list = map {s|$home/||; $_} grep {-d} glob("$home/*");
   return \@list;
 }
