@@ -3,6 +3,7 @@ package App::Netdisco::Web::Search;
 use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
+use Dancer::Plugin::Auth::Extensible;
 
 hook 'before' => sub {
   # view settings for node options
@@ -59,13 +60,13 @@ hook 'before_template' => sub {
   }
 };
 
-get '/search' => sub {
+get '/search' => require_login sub {
     my $q = param('q');
     my $s = schema('netdisco');
 
     if (not param('tab')) {
         if (not $q) {
-            return redirect uri_for('/')->path_query;
+            return redirect uri_for('/')->path;
         }
 
         # pick most likely tab for initial results
@@ -82,7 +83,7 @@ get '/search' => sub {
                       tab => 'details',
                       q => ($nd->first->dns || $nd->first->ip),
                       f => '',
-                    })->path_query;
+                    })->path;
                 }
 
                 # multiple devices
@@ -104,6 +105,7 @@ get '/search' => sub {
     my $vendor_list = [ $s->resultset('Device')->get_distinct_col('vendor') ];
 
     template 'search', {
+      search => params->{'tab'},
       model_list  => $model_list,
       os_ver_list => $os_ver_list,
       vendor_list => $vendor_list,
